confintRegression <- function(model, predictor, level) {
  .check_model(model)

  newdata <- data.frame(predictor)
  colnames(newdata) <- names(coef(model))[2]

  conf <- predict(model, interval = "conf", level = level, newdata = newdata)
  pred <- predict(model, interval = "pred", level = level, newdata = newdata)

  x <- rbind(conf, pred)
  rownames(x) <- c("Modell", "Vorhersage")

  return(x)
}





ConfintRegression <- function () {
  .activeModel <- ActiveModel()

  # check for correct model before Tcl window appears
  # don't call .check_model directly, error message needs Rcmdr context
  err <- try(.check_model(get(.activeModel)), silent = T)
  if(!is.null(err)) {
    Message(attr(err, "condition")$message, type = "error")
    return()
  }

  onOK <- function() {
    # retrieve the values (character strings) from the tcl dialog
    level <- tclvalue(confLevel)
    pred <- tclvalue(predictor)

    # ignore warnings; because of the following as.numeric()?
    opts <- options(warn = -1)
    options(opts)

    closeDialog()

    lev <- as.numeric(level)
    if (is.na(lev) || !is.numeric(lev) || lev < 0 || lev > 1) {
      txt <- "Niveau des Konfidenzintervalls muss zwischen 0 und 1 liegen."
      Message(gettextRcmdr(txt), type = "error")

      # restart on invalid input
      ConfintRegression()
      return()
    }

    pre <- as.numeric(pred)
    if (is.na(pre) || !is.numeric(pre)) {
      txt <- "Wert der abhaengigen Variablen muss numerisch sein."
      Message(gettextRcmdr(txt), type = "error")

      ConfintRegression()
      return()
    }

    # finally writing variables to envir = RcmdrEnv()
    putDialog("confidenceIntervals2",
              list(initial.level = level, initial.predictor = pred))

    # execute the corresponding R command
    command <- paste0("confintRegression(model = ", .activeModel,
                      ", predictor = ", pred, ", level = ", level, ")")
    doItAndPrint(command)
    tkfocus(CommanderWindow())
  }

  defaults <- list(initial.level = "0.95", initial.predictor = "")
  dialog.values <- getDialog("confidenceIntervals2", defaults)

  dialogLabel <- gettextRcmdr("Regression Konfidenzintervalle")
  initializeDialog(title = dialogLabel)
  tkgrid(labelRcmdr(top, text = dialogLabel), sticky = "w")

  OKCancelHelp(helpSubject = "confintRegression")

  confidenceFrame <- tkframe(top)

  confLevel <- tclVar(dialog.values$initial.level)
  confField <- ttkentry(confidenceFrame, width = "6", textvariable = confLevel)

  predictor <- tclVar(dialog.values$initial.predictor)
  predField <- ttkentry(confidenceFrame, width = "6", textvariable = predictor)

  txt <- gettextRcmdr("Niveau des Konfidenzintervalls: ")
  tkgrid(labelRcmdr(confidenceFrame, text = txt), confField, sticky = "w")

  expl.var <- names(coefficients(get(.activeModel)))[2]
  txt <- gettextRcmdr(paste0("Wert der abh. Variable ", sQuote(expl.var), ": "))
  tkgrid(labelRcmdr(confidenceFrame, text = txt), predField, sticky = "w")

  tkgrid(confidenceFrame, sticky = "w")
  tkgrid(buttonsFrame, sticky = "w")
  dialogSuffix()
}
