scatterplotRegression <- function(model) {
  .check_model(model)
  mf <- model.frame(model)

  hilfswerte <- data.frame(seq(min(mf[, 2]), max(mf[, 2]), length.out = 100))
  colnames(hilfswerte) <- colnames(mf)[2]

  konfidenzband <- predict(model, hilfswerte, interval = "conf")
  vorhersageband <- predict(model, hilfswerte, interval = "pred")

  scatterplot(formula(model), data = mf,
              ylim = range(c(mf[, 1], konfidenzband, vorhersageband)),
              reg.line = lm, smooth = FALSE, spread = FALSE, boxplots = FALSE,
              span = 0.5, col = 1)

  matlines(hilfswerte[, 1], konfidenzband[, c("lwr", "upr")],
           lty = 3, col = 1)

  matlines(hilfswerte[, 1], vorhersageband[, c("lwr", "upr")],
           lty = 2, col = 2)

  legend("bottomright", legend = c("Beobachtung", "Modell",
                                   "Konfidenzintervall", "Vorhersageintervall"),
         lty = c(0, 1, 3, 3),
         pch = c(1, rep(NA, 3)),
         col = c(1, 1, 1, 2),
         bg = "white")
}

ScatterplotRegression <- function() {
  .activeModel <- ActiveModel()

  # execute the corresponding R command
  command <- paste0("scatterplotRegression(model = ", .activeModel, ")")
  doItAndPrint(command)
}




