\name{confintRegression}
\alias{confintRegression}
\alias{ConfintRegression}

\title{Regression Konfidenzintervalle}

\description{
Schaetzung der Konfidenzintervalle fuer Regressionsgerade und Vorhersagewert
eines linearen Modells.
}

\usage{
confintRegression(model, predictor, level)
ConfintRegression()
}

\arguments{
  \item{model}{Ein Objekt der Klasse 'lm' (lineares Modell).}
  \item{predictor}{Wert der abhaengigen Variable des linearen Modells.}
  \item{level}{Konfidenzniveau des Intervalls.}
}

\details{
\code{ConfintRegression} ist ein Wrapper um \code{confintRegression}, aufgerufen
vom R-Commander.
}

\value{
Eine Matrix mit dem Schaetzwert des Modells und den Grenzen des
Konfidenzintervalls. }

\examples{
gras <- data.frame(grasanteil = c(0, 5, 10, 15, 20, 25, 30, 35),
                   ertrag = c(116.8, 117.1, 115.4, 118.3, 118.8,
                              124.6, 120.5, 122.7))
lm1 <- lm(ertrag ~ grasanteil, data = gras)

### Bsp. Konfidenzintervall
# Ein beidseitig beschraenktes 95\%-iges Konfidenzintervall fuer den
# erwartetenErtrag bei einem Grasanteil von 20\% soll berechnet werden.

confintRegression(lm1, predictor = 20, level = 0.95)

# Damit erhalten wir als Grenzen eines 95\%-igen Konfidenzintervalls
# fuer den erwarteten Ertrag bei einem Grasanteil von 20\% 118.0 und
# 121.6 dt/ha.



### Bsp. Vorhersageintervall
# Um ein nach oben beschraenktes 90\%-iges Vorhersageintervall fuer
# einen (gemessenen) Ertrag bei einem Grasanteil von 25\% berechnen zu
# koennen, muss das Signifikanzniveau \code{alpha} fuer das
# Konfidenzintervall verdoppelt werden.

confintRegression(lm1, predictor = 25, level = 0.80)

# Damit erhalten wir als obere Grenze eines nach oben beschraenkten
# 90\%-igen Vorhersageintervalls fuer einen (gemessenen) Ertrag bei
# einem Grasanteil von 25\% 124.0 dt/ha.
}
